@@ -110,11 +110,11 @@ func isOOD(cwd, tgtOrig string, level int, seen map[string]struct{}) (bool, erro
 	for _, m := range depInfo.ifchanges {
 		dep := m["Target"]
 		if dep == "" {
-			return ood, TgtErr{tgtOrig, errors.New("invalid format of .dep: missing Target")}
+			return ood, TgtErr{tgtOrig, errors.New("invalid format of .rec: missing Target")}
 		}
 		theirInode, err := inodeFromRec(m)
 		if err != nil {
-			return ood, TgtErr{tgtOrig, fmt.Errorf("invalid format of .dep: %v", err)}
+			return ood, TgtErr{tgtOrig, fmt.Errorf("invalid format of .rec: %v", err)}
 		}
 		theirHsh := m["Hash"]
 		trace(CDebug, "ood: %s%s -> %s: checking", indent, tgtOrig, dep)
