@@ -20,6 +20,7 @@ package main
 import (
 	"flag"
 	"fmt"
+	"log"
 	"os"
 )
 
@@ -57,7 +58,7 @@ func statusInit() {
 	var err error
 	r, FdStatus, err = os.Pipe()
 	if err != nil {
-		panic(err)
+		log.Fatalln(err)
 	}
 	go func() {
 		running := 0
